Frame

Enum Frame 

pub enum Frame {
    Subscribe {
        id: u64,
        channel: String,
    },
    Unsubscribe {
        id: u64,
        channel: String,
    },
    Publish {
        id: Option<u64>,
        channel: String,
        event: Option<String>,
        payload: Vec<u8>,
    },
    Presence {
        id: u64,
        channel: String,
        action: PresenceAction,
        data: Option<Value>,
    },
    Ack {
        id: u64,
    },
    Error {
        id: u64,
        code: u16,
        message: String,
    },
    Ping {
        timestamp: Option<u64>,
    },
    Pong {
        timestamp: Option<u64>,
    },
    Connect {
        version: u8,
        token: Option<String>,
    },
    Connected {
        connection_id: String,
        version: u8,
        heartbeat: u32,
    },
}
A protocol frame.

Frames are the messages exchanged between clients and servers. Each frame type has specific fields relevant to its operation.

Variants



Subscribe

Subscribe to a channel.

Fields

id: u64

Request ID for acknowledgment.

channel: String

Channel name to subscribe to.



Unsubscribe

Unsubscribe from a channel.

Fields

id: u64

Request ID for acknowledgment.

channel: String

Channel name to unsubscribe from.



Publish

Publish a message to a channel.

Fields

id: Option<u64>

Optional request ID for acknowledgment.

channel: String

Target channel.

event: Option<String>

Optional event name.

payload: Vec<u8>

Message payload.



Presence

Presence update.

Fields

id: u64

Request ID.

channel: String

Channel name.

action: PresenceAction

Presence action.

data: Option<Value>

Optional presence metadata.



Ack

Acknowledgment of a request.

Fields

id: u64

ID of the acknowledged request.



Error

Error response.

Fields

id: u64

ID of the failed request (0 if not applicable).

code: u16

Error code.

message: String

Human-readable error message.



Ping

Keepalive ping.

Fields

timestamp: Option<u64>

Optional timestamp.



Pong

Keepalive pong.

Fields

timestamp: Option<u64>

Echoed timestamp from ping.



Connect

Initial connection handshake.

Fields

version: u8

Protocol version.

token: Option<String>

Optional authentication token.



Connected

Connection established response.

Fields

connection_id: String

Unique connection identifier.

version: u8

Negotiated protocol version.

heartbeat: u32

Recommended heartbeat interval in milliseconds.

Implementations

Source

impl Frame

pub fn frame_type(&self) -> FrameType

Get the frame type.

pub fn subscribe(id: u64, channel: impl Into<String>) -> Self

Create a new Subscribe frame.

pub fn unsubscribe(id: u64, channel: impl Into<String>) -> Self

Create a new Unsubscribe frame.

pub fn publish(channel: impl Into<String>, payload: impl Into<Vec<u8>>) -> Self

Create a new Publish frame.

pub fn publish_with_ack( id: u64, channel: impl Into<String>, payload: impl Into<Vec<u8>>, ) -> Self

Create a new Publish frame with ID for acknowledgment.

pub fn ack(id: u64) -> Self

Create a new Ack frame.

pub fn error(id: u64, code: u16, message: impl Into<String>) -> Self

Create a new Error frame.

pub fn ping() -> Self

Create a new Ping frame.

pub fn ping_with_timestamp(timestamp: u64) -> Self

Create a new Ping frame with timestamp.

pub fn pong(timestamp: Option<u64>) -> Self

Create a new Pong frame.

pub fn connect(version: u8, token: Option<String>) -> Self

Create a new Connect frame.

pub fn connected( connection_id: impl Into<String>, version: u8, heartbeat: u32, ) -> Self

Create a new Connected frame.